"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatOpt = exports.formatUrl = exports.getStyles = exports.getScripts = void 0;

function _utils() {
  const data = require("@umijs/utils");

  _utils = function _utils() {
    return data;
  };

  return data;
}

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const EXP_URL = /^(http:|https:)?\/\//;
/**
 * 格式化 script => object
 * @param option Array<string | IScript>
 */

const getScripts = option => {
  if (Array.isArray(option) && option.length > 0) {
    return option.filter(script => !_utils().lodash.isEmpty(script)).map(aScript => {
      if (typeof aScript === 'string') {
        return EXP_URL.test(aScript) ? {
          src: aScript
        } : {
          content: aScript
        };
      } // [{ content: '', async: true, crossOrigin: true }]


      return aScript;
    });
  }

  return [];
};
/**
 * 格式化 styles => [linkObject, styleObject]
 * @param option Array<string | ILink>
 */


exports.getScripts = getScripts;

const getStyles = option => {
  const linkArr = [];
  const styleObj = [];

  if (Array.isArray(option) && option.length > 0) {
    option.forEach(style => {
      if (typeof style === 'string') {
        if (EXP_URL.test(style)) {
          // is <link />
          linkArr.push({
            charset: 'utf-8',
            rel: 'stylesheet',
            type: 'text/css',
            href: style
          });
        } else {
          styleObj.push({
            content: style
          });
        }
      }

      if (typeof style === 'object') {
        // is style object
        styleObj.push(style);
      }
    });
  }

  return [linkArr, styleObj];
};

exports.getStyles = getStyles;

const formatUrl = (item, base) => {
  if (typeof item === 'string') {
    return base ? new URL(item, base).toString() : item;
  }

  return item.base || base ? new URL(item.url, item.base || base).toString() : item.url;
};

exports.formatUrl = formatUrl;

const formatOpt = assets => {
  const cdnJs = {};
  const cdnCss = {};
  Object.entries(assets.js || {}).forEach(([key, item]) => {
    if (item) {
      cdnJs[key] = _objectSpread(_objectSpread({}, item), {}, {
        url: formatUrl(item, assets.base)
      });
    }
  });
  Object.entries(assets.css || {}).forEach(([key, item]) => {
    if (typeof item === 'string') {
      cdnCss[key] = {
        url: formatUrl(item, assets.base)
      };
    } else if (item) {
      cdnCss[key] = _objectSpread(_objectSpread({}, item), {}, {
        url: formatUrl(item, assets.base)
      });
    }
  });
  return {
    js: cdnJs,
    css: cdnCss
  };
};

exports.formatOpt = formatOpt;